# `pptestmateuszlis` - My simple first project on PyPI

* Op1
* Op2
* Op3

# Install

```python
pip install pptestmateuszlis
```
### Usage 
```python
from pptestmateuszlis.m_mod_pptest import name as n

>>> n("Name", "Surname")
Witaj: Name Surname
>>> get_numpy_array([1, 2, 3, 4])
[1, 2, 3, 4]
```